
from vsg.rules import line_below_rule


class rule_017(line_below_rule):
    '''
    Architecture rule 017 checks for a blank line below the "begin" keyword.
    '''

    def __init__(self):
        line_below_rule.__init__(self, 'architecture', '017', 'isArchitectureBegin')




from vsg.rules import indent_rule


class rule_001(indent_rule):
    '''
    Assert rule 001 checks for spaces at the beginning of the line.
    '''

    def __init__(self):
        indent_rule.__init__(self)
        self.name = 'assert'
        self.identifier = '001'
        self.sTrigger = 'insideAssert'




from vsg.rules import lowercase_word_after_colon_rule


class rule_011(lowercase_word_after_colon_rule):
    '''
    Signal rule 010 checks the signal type is lowercase.
    '''

    def __init__(self):
        lowercase_word_after_colon_rule.__init__(self, 'signal', '011', 'isSignal', False)
        self.solution = 'Change signal type to lowercase.'



import re


def assert_statement(dVars, oLine):

    if re.match('^\s*assert', oLine.line, re.IGNORECASE):
        oLine.isAssertKeyword = True
        oLine.insideAssert = True
    if oLine.insideAssert:
        oLine.indentLevel = dVars['iCurrentIndentLevel']
    if oLine.insideAssert and ';' in oLine.line:
        oLine.isAssertEnd = True




from vsg import rule


class rule_006(rule.rule):
    '''
    Sequential rule 006 checks for commented out lines within a multiline sequential statement.
    '''

    def __init__(self):
        rule.rule.__init__(self, 'sequential', '006')
        self.solution = 'Remove comment.'
        self.phase = 1

    def analyze(self, oFile):
        for iLineNumber, oLine in enumerate(oFile.lines):
            if oLine.insideSequential and oLine.isComment:
                self.add_violation(iLineNumber)

    def _fix_violations(self, oFile):
        for iLineNumber in self.violations[::-1]:
            oFile.lines.pop(iLineNumber)




from vsg.rules import single_space_before_character_rule


class rule_024(single_space_before_character_rule):
    '''
    Process rule 024 checks for a single space after the process label and the :.
    '''

    def __init__(self):
        single_space_before_character_rule.__init__(self, 'process', '024', 'isProcessLabel', ':')
        self.solution = 'Ensure a single space exists between process label and :.'
